﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using Phone位置导航.Resources;
using Windows.Devices.Geolocation;
using System.IO.IsolatedStorage;

namespace Phone位置导航
{
    public partial class MainPage : PhoneApplicationPage
    {
        // 构造函数
        public MainPage()
        {
            InitializeComponent();
        }

        Geolocator geolocator = null;
        bool tracking = false;

        private async void OneShotLocation_Click(object sender, RoutedEventArgs e)
        {
            //地理位置访问服务
            Geolocator geolocator = new Geolocator();
            //定义精度，米为单位
            geolocator.DesiredAccuracyInMeters = 1;

            try
            {
                //开始获取当前位置的经纬度
                Geoposition geoposition = await geolocator.GetGeopositionAsync();
                LatitudeTextBlock.Text = "经度：" + geoposition.Coordinate.Latitude.ToString("0.00");
                LongitudeTextBlock.Text = "纬度：" + geoposition.Coordinate.Longitude.ToString("0.00");
            }
            catch (Exception ex)
            {
                if ((uint)ex.HResult == 0x80004004)
                {
                    StatusTextBlock.Text = "系统设置关闭了位置服务.";
                }

            }
        }


        private void TrackLocation_Click(object sender, RoutedEventArgs e)
        {

            if (!tracking)
            {
                //地理位置访问服务
                geolocator = new Geolocator();
                //精度级别
                geolocator.DesiredAccuracy = PositionAccuracy.High;
                //超过多少米引发位置改变事件
                geolocator.MovementThreshold = 100;

                //功能状态改变时
                geolocator.StatusChanged += geolocator_StatusChanged;
                //位置改变时
                geolocator.PositionChanged += geolocator_PositionChanged;

                tracking = true;
                TrackLocationButton.Content = "停止跟踪";
            }
            else
            {
                geolocator.PositionChanged -= geolocator_PositionChanged;
                geolocator.StatusChanged -= geolocator_StatusChanged;
                geolocator = null;

                tracking = false;
                TrackLocationButton.Content = "跟踪位置";
                StatusTextBlock.Text = "停止";
            }
        }

        void geolocator_StatusChanged(Geolocator sender, StatusChangedEventArgs args)
        {
            string status = "";

            switch (args.Status)
            {
                case PositionStatus.Disabled:
                    status = "位置服务设置被禁用";
                    break;
                case PositionStatus.Initializing:
                    status = "正在初始化";
                    break;
                case PositionStatus.NoData:
                    status = "无数据";
                    break;
                case PositionStatus.Ready:
                    status = "已准备";
                    break;
                case PositionStatus.NotAvailable:
                    status = "无法使用";
                    break;
                case PositionStatus.NotInitialized:
                    break;
            }
            Dispatcher.BeginInvoke(() =>
            {
                StatusTextBlock.Text = status;
            });
        }

        void geolocator_PositionChanged(Geolocator sender, PositionChangedEventArgs args)
        {
            if (!App.RunningInBackground)
            {
                Dispatcher.BeginInvoke(() =>
                {
                    LatitudeTextBlock.Text = "经度：" + args.Position.Coordinate.Latitude.ToString("0.00");
                    LongitudeTextBlock.Text = "纬度：" + args.Position.Coordinate.Longitude.ToString("0.00");
                });
            }
            else
            {
                Microsoft.Phone.Shell.ShellToast toast = new Microsoft.Phone.Shell.ShellToast();
                toast.Content = args.Position.Coordinate.Latitude.ToString("0.00") + "," + args.Position.Coordinate.Longitude.ToString("0.00");
                toast.Title = "位置：";
                toast.NavigationUri = new Uri("/Page1.xaml", UriKind.Relative);
                toast.Show();

            }


        }

        protected override void OnNavigatedTo(System.Windows.Navigation.NavigationEventArgs e)
        {
            if (App.Geolocator == null)
            {
                App.Geolocator = new Geolocator();
                App.Geolocator.DesiredAccuracy = PositionAccuracy.High;
                App.Geolocator.MovementThreshold = 100;
                App.Geolocator.PositionChanged += geolocator_PositionChanged;
            }
        }


    }
}